%global apiversion   0.3
%global spaversion   0.2
%global ms_version   0.4.1

Summary:        Media Sharing Server
Name:           pipewire
Version:        0.3.85
Release:        10%{?dist}
License:        MIT
URL:            https://pipewire.org/
Source0:        https://gitlab.freedesktop.org/pipewire/pipewire/-/archive/%{version}/pipewire-%{version}.tar.gz

BuildRequires:  meson >= 0.59.0 gcc g++ pkgconfig
BuildRequires:  pkgconfig(libudev) pkgconfig(dbus-1) pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.32 pkgconfig(gstreamer-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-base-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-net-1.0) >= 1.10.0
BuildRequires:  pkgconfig(gstreamer-allocators-1.0) >= 1.10.0
BuildRequires:  pkgconfig(fdk-aac)
BuildRequires:  pkgconfig(vulkan) pkgconfig(bluez)
BuildRequires:  systemd systemd-devel alsa-lib-devel
BuildRequires:  libv4l-devel sbc-devel libsndfile-devel ncurses-devel
BuildRequires:  doxygen gettext readline-devel python-docutils
BuildRequires:  graphviz pulseaudio-libs-devel avahi-devel
BuildRequires:  pkgconfig(webrtc-audio-processing) >= 0.2
BuildRequires:  libusb1-devel openssl-devel libcanberra-devel libmysofa-devel

Requires(pre):  shadow-utils
Requires:       %{name}-libs = %{version}-%{release}
Requires:       systemd
Requires:       rtkit
Requires:       pipewire-session-manager
Suggests:       wireplumber

%description
PipeWire is a project that aims to greatly improve handling of audio and
video under Linux. It provides a low-latency, graph-based processing engine
on top of audio and video devices that can be used to support the use cases
currently handled by both PulseAudio and JACK. PipeWire was designed with a
powerful security model that makes interacting with audio and video devices
from containerized applications easy, with support for Flatpak applications
being the primary goal. Alongside Wayland and Flatpak, we expect PipeWire to
provide a core building block for the future of Linux application development.

%package libs
Summary:        Libraries for PipeWire clients
License:        MIT
Recommends:     %{name} = %{version}-%{release}

%description libs
This package contains the runtime libraries for any application that wishes
to interface with a PipeWire media server.

%package gstreamer
Summary:        GStreamer elements for PipeWire
License:        MIT
Recommends:     %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description gstreamer
This package contains GStreamer elements to interface with a
PipeWire media server.

%package devel
Summary:        Headers and libraries for PipeWire client development
License:        MIT
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Headers and libraries for developing applications that can communicate with
a PipeWire media server.

%package utils
Summary:        PipeWire media server utilities
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description utils
This package contains command line utilities for the PipeWire media server.

%package alsa
Summary:        PipeWire media server ALSA support
License:        MIT
Recommends:     %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description alsa
This package contains an ALSA plugin for the PipeWire media server.

%package v4l2
Summary:        PipeWire media server v4l2 LD_PRELOAD support
License:        MIT
Recommends:     %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description v4l2
This package contains an LD_PRELOAD library that redirects v4l2 applications to
PipeWire.

%package pulseaudio
Summary:        PipeWire PulseAudio implementation
License:        MIT
Recommends:     %{name} = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Conflicts:      pulseaudio
Obsoletes:      pulseaudio
Supplements:    %{name} = %{version}-%{release}

Provides:       pulseaudio-daemon
Provides:       pulseaudio-module-bluetooth
Obsoletes:      pulseaudio-module-bluetooth
Provides:       pulseaudio-module-jack

%description pulseaudio
This package provides a PulseAudio implementation based on PipeWire

%prep
%autosetup -p1


%build
%meson \
    -D docs=disabled -D man=enabled -D gstreamer=enabled -D systemd=enabled \
    -D gstreamer-device-provider=disabled \
    -D sdl2=disabled \
    -D audiotestsrc=disabled \
    -D videotestsrc=disabled \
    -D volume=disabled \
    -D bluez5-codec-aptx=disabled \
    -D bluez5-codec-ldac=disabled \
    -D bluez5-codec-lc3plus=disabled \
    -D session-managers=[] \
    -D pipewire-jack=disabled \
    -D jack=disabled \
    -D libcamera=disabled \
    -D lv2=disabled \
    -D roc=disabled \
    -D libffado=disabled \
    -D bluez5-codec-lc3plus=disabled \
    -D bluez5-codec-lc3=disabled \
    -D vulkan=enabled
%meson_build

%install
%meson_install

rm %{buildroot}%{_datadir}/pipewire/jack.conf
mkdir -p %{buildroot}%{_sysconfdir}/alsa/conf.d/
cp %{buildroot}%{_datadir}/alsa/alsa.conf.d/50-pipewire.conf \
        %{buildroot}%{_sysconfdir}/alsa/conf.d/50-pipewire.conf
cp %{buildroot}%{_datadir}/alsa/alsa.conf.d/99-pipewire-default.conf \
        %{buildroot}%{_sysconfdir}/alsa/conf.d/99-pipewire-default.conf


install -d -m 0755 %{buildroot}%{_datadir}/pipewire/pipewire-pulse.conf.d/

%find_lang %{name}

mkdir -p %{buildroot}%{_prefix}/lib/udev/rules.d
mv -fv %{buildroot}/lib/udev/rules.d/90-pipewire-alsa.rules %{buildroot}%{_prefix}/lib/udev/rules.d


%check
%meson_test

%pre
getent group pipewire >/dev/null || groupadd -r pipewire
getent passwd pipewire >/dev/null || \
    useradd -r -g pipewire -d %{_localstatedir}/run/pipewire -s /sbin/nologin -c "PipeWire System Daemon" pipewire
exit 0

%post
%systemd_user_post pipewire.service
%systemd_user_post pipewire.socket

%post pulseaudio
%systemd_user_post pipewire-pulse.service
%systemd_user_post pipewire-pulse.socket

%files
%license LICENSE COPYING
%doc README.md
%{_userunitdir}/pipewire.*
%{_userunitdir}/filter-chain.*
%{_bindir}/pipewire
%{_bindir}/pipewire-avb
%{_bindir}/pipewire-aes67
%{_bindir}/pipewire-vulkan
%dir %{_datadir}/pipewire/
%{_datadir}/pipewire/pipewire.conf
%{_datadir}/pipewire/minimal.conf
%{_datadir}/pipewire/filter-chain.conf
%{_datadir}/pipewire/filter-chain/*.conf
%{_datadir}/pipewire/pipewire-avb.conf
%{_datadir}/pipewire/pipewire-vulkan.conf
%{_datadir}/pipewire/client-rt.conf.avail/20-upmix.conf
%{_datadir}/pipewire/client.conf.avail/20-upmix.conf
%{_datadir}/pipewire/pipewire-aes67.conf
%{_datadir}/pipewire/pipewire.conf.avail/10-rates.conf
%{_datadir}/pipewire/pipewire.conf.avail/20-upmix.conf
%{_sysconfdir}/security/limits.d/25-pw-rlimits.conf
%{_mandir}/man5/pipewire.conf.5*
%{_mandir}/man1/pipewire.1*

%files libs -f %{name}.lang
%license LICENSE COPYING
%doc README.md
%{_libdir}/libpipewire-%{apiversion}.so.*
%{_libdir}/pipewire-%{apiversion}/libpipewire-*.so
%dir %{_datadir}/alsa-card-profile/
%dir %{_datadir}/alsa-card-profile/mixer/
%{_datadir}/alsa-card-profile/mixer/paths/
%{_datadir}/alsa-card-profile/mixer/profile-sets/
%dir %{_datadir}/spa-0.2/
%{_datadir}/spa-0.2/bluez5/bluez-hardware.conf
%{_prefix}/lib/udev/rules.d/90-pipewire-alsa.rules
%dir %{_libdir}/spa-%{spaversion}
%{_libdir}/spa-%{spaversion}/aec/
%{_libdir}/spa-%{spaversion}/alsa/
%{_libdir}/spa-%{spaversion}/audioconvert/
%{_libdir}/spa-%{spaversion}/audiomixer/
%{_libdir}/spa-%{spaversion}/avb/
%{_libdir}/spa-%{spaversion}/bluez5/
%{_libdir}/spa-%{spaversion}/control/
%{_libdir}/spa-%{spaversion}/support/
%{_libdir}/spa-%{spaversion}/v4l2/
%{_libdir}/spa-%{spaversion}/videoconvert/
%{_libdir}/spa-%{spaversion}/vulkan/
%{_datadir}/pipewire/client.conf
%{_datadir}/pipewire/client-rt.conf

%files gstreamer
%{_libdir}/gstreamer-1.0/libgstpipewire.*

%files devel
%{_libdir}/libpipewire-%{apiversion}.so
%{_includedir}/pipewire-%{apiversion}/
%{_includedir}/spa-%{spaversion}/
%{_libdir}/pkgconfig/libpipewire-%{apiversion}.pc
%{_libdir}/pkgconfig/libspa-%{spaversion}.pc

%files utils
%{_bindir}/spa-acp-tool
%{_bindir}/spa-inspect
%{_bindir}/spa-json-dump
%{_bindir}/spa-monitor
%{_bindir}/spa-resample
%{_bindir}/pw-mon
%{_bindir}/pw-metadata
%{_bindir}/pw-dsdplay
%{_bindir}/pw-mididump
%{_bindir}/pw-midiplay
%{_bindir}/pw-midirecord
%{_bindir}/pw-cli
%{_bindir}/pw-dot
%{_bindir}/pw-cat
%{_bindir}/pw-dump
%{_bindir}/pw-link
%{_bindir}/pw-loopback
%{_bindir}/pw-play
%{_bindir}/pw-profiler
%{_bindir}/pw-record
%{_bindir}/pw-reserve
%{_bindir}/pw-top
%{_bindir}/pw-config
%{_bindir}/pw-encplay
%{_mandir}/man1/pw-mon.1*
%{_mandir}/man1/pw-cli.1*
%{_mandir}/man1/pw-cat.1*
%{_mandir}/man1/pw-dot.1*
%{_mandir}/man1/pw-link.1*
%{_mandir}/man1/pw-metadata.1*
%{_mandir}/man1/pw-mididump.1*
%{_mandir}/man1/pw-profiler.1*
%{_mandir}/man1/pw-top.1*
%{_mandir}/man1/pw-config.1.gz

%files alsa
%{_libdir}/alsa-lib/libasound_module_pcm_pipewire.so
%{_libdir}/alsa-lib/libasound_module_ctl_pipewire.so
%{_datadir}/alsa/alsa.conf.d/50-pipewire.conf
%{_datadir}/alsa/alsa.conf.d/99-pipewire-default.conf
%config(noreplace) %{_sysconfdir}/alsa/conf.d/50-pipewire.conf
%config(noreplace) %{_sysconfdir}/alsa/conf.d/99-pipewire-default.conf

%files v4l2
%{_bindir}/pw-v4l2
%{_libdir}/pipewire-%{apiversion}/v4l2/libpw-v4l2.so

%files pulseaudio
%{_bindir}/pipewire-pulse
%{_userunitdir}/pipewire-pulse.*
%{_datadir}/pipewire/pipewire-pulse.conf
%dir %{_datadir}/pipewire/pipewire-pulse.conf.d/
%{_datadir}/pipewire/pipewire-pulse.conf.avail/20-upmix.conf
%{_libdir}/pipewire-%{apiversion}/libpipewire-module-protocol-pulse.so
%{_mandir}/man1/pipewire-pulse.1*

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.3.85-10
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.3.85-9
- Rebuilt for loongarch release

* Mon Dec 25 2023 luffyluo <luffyluo@tencent.com> - 0.3.85-8
- Rebuilt for vulkan-loader 1.3.268.0

* Tue Nov 14 2023 cunshunxia@tencent.com - 0.3.77-7
- obsoletes the pulseaudio-module-bluetooth.

* Tue Nov 14 2023 cunshunxia@tencent.com - 0.3.77-6
- add audio subpkg and fix audio device detection problem.

* Mon Nov 13 2023 cunshunxia@tencent.com - 0.3.77-5
- Rebuilt for libsndfile 1.2.0-4

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.3.77-4
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 kianli <kianli@tencent.com> - 0.3.77-3
- Rebuilt for v4l-utils 1.24.1

* Thu Aug 17 2023 Shuo Wang <abushwang@tencent.com> - 0.3.77-2
- Rebuilt for vulkan-loader 1.3.250.0

* Wed Aug 16 2023 cunshunxia <cunshunxia@tencent.com> - 0.3.77-1
- upgrade to 0.3.77

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.3.60-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.3.60-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Jan 11 2023 cunshunxia <cunshunxia@tencent.com> - 0.3.60-2
- rebuild for vulkan loader upgrade.

* Wed Nov 23 2022 cunshunxia <cunshunxia@tencent.com> - 0.3.60-1
- initial build
